==> ooo_dev_tools-0.9.0.tar.gz: ooo_dev_tools-0.9.0/ooodev/format/writer/modify/page/header/area/__init__.py <==
import uno
from ooo.dyn.awt.gradient_style import GradientStyle as GradientStyle
from ooo.dyn.drawing.hatch_style import HatchStyle as HatchStyle
from ooo.dyn.drawing.rectangle_point import RectanglePoint as RectanglePoint

from ooodev.format.inner.common.format_types.offset_column import OffsetColumn as OffsetColumn
from ooodev.format.inner.common.format_types.offset_row import OffsetRow as OffsetRow
from ooodev.format.inner.common.format_types.size_percent import SizePercent as SizePercent
from ooodev.format.inner.direct.write.fill.area.img import ImgStyleKind as ImgStyleKind
from ooodev.format.inner.modify.write.page.header.area.color import Color as Color
from ooodev.format.inner.modify.write.page.header.area.color import InnerColor as InnerColor
from ooodev.format.inner.modify.write.page.header.area.gradient import Gradient as Gradient
from ooodev.format.inner.modify.write.page.header.area.gradient import InnerGradient as InnerGradient
from ooodev.format.inner.modify.write.page.header.area.hatch import Hatch as Hatch
from ooodev.format.inner.modify.write.page.header.area.hatch import InnerHatch as InnerHatch
from ooodev.format.inner.modify.write.page.header.area.img import Img as Img
from ooodev.format.inner.modify.write.page.header.area.img import InnerImg as InnerImg
from ooodev.format.inner.modify.write.page.header.area.pattern import InnerPattern as InnerPattern
from ooodev.format.inner.modify.write.page.header.area.pattern import Pattern as Pattern
from ooodev.format.inner.preset.preset_gradient import PresetGradientKind as PresetGradientKind
from ooodev.format.inner.preset.preset_hatch import PresetHatchKind as PresetHatchKind
from ooodev.format.inner.preset.preset_image import PresetImageKind as PresetImageKind
from ooodev.format.inner.preset.preset_pattern import PresetPatternKind as PresetPatternKind
from ooodev.utils.data_type.angle import Angle as Angle
from ooodev.utils.data_type.color_range import ColorRange as ColorRange
from ooodev.utils.data_type.intensity import Intensity as Intensity
from ooodev.utils.data_type.intensity_range import IntensityRange as IntensityRange
from ooodev.utils.data_type.size_mm import SizeMM as SizeMM

__all__ = [
    "OffsetColumn",
    "OffsetRow",
    "SizePercent",
    "ImgStyleKind",
    "Color",
    "InnerColor",
    "Gradient",
    "InnerGradient",
    "Hatch",
    "InnerHatch",
    "Img",
    "InnerImg",
    "InnerPattern",
    "Pattern",
    "PresetGradientKind",
    "PresetHatchKind",
    "PresetImageKind",
    "PresetPatternKind",
]

==> ooo_dev_tools-0.28.1.tar.gz: ooo_dev_tools-0.28.1/ooodev/format/writer/modify/page/header/area/__init__.py <==
import uno
from ooo.dyn.awt.gradient_style import GradientStyle as GradientStyle
from ooo.dyn.drawing.hatch_style import HatchStyle as HatchStyle
from ooo.dyn.drawing.rectangle_point import RectanglePoint as RectanglePoint

from ooodev.format.writer.style.page.kind.writer_style_page_kind import WriterStylePageKind as WriterStylePageKind
from ooodev.format.inner.common.format_types.offset_column import OffsetColumn as OffsetColumn
from ooodev.format.inner.common.format_types.offset_row import OffsetRow as OffsetRow
from ooodev.format.inner.common.format_types.size_percent import SizePercent as SizePercent
from ooodev.format.inner.direct.write.fill.area.img import ImgStyleKind as ImgStyleKind
from ooodev.format.inner.modify.write.page.header.area.color import Color as Color
from ooodev.format.inner.modify.write.page.header.area.color import InnerColor as InnerColor
from ooodev.format.inner.modify.write.page.header.area.gradient import Gradient as Gradient
from ooodev.format.inner.modify.write.page.header.area.gradient import InnerGradient as InnerGradient
from ooodev.format.inner.modify.write.page.header.area.hatch import Hatch as Hatch
from ooodev.format.inner.modify.write.page.header.area.hatch import InnerHatch as InnerHatch
from ooodev.format.inner.modify.write.page.header.area.img import Img as Img
from ooodev.format.inner.modify.write.page.header.area.img import InnerImg as InnerImg
from ooodev.format.inner.modify.write.page.header.area.pattern import InnerPattern as InnerPattern
from ooodev.format.inner.modify.write.page.header.area.pattern import Pattern as Pattern
from ooodev.format.inner.preset.preset_gradient import PresetGradientKind as PresetGradientKind
from ooodev.format.inner.preset.preset_hatch import PresetHatchKind as PresetHatchKind
from ooodev.format.inner.preset.preset_image import PresetImageKind as PresetImageKind
from ooodev.format.inner.preset.preset_pattern import PresetPatternKind as PresetPatternKind
from ooodev.units import Angle as Angle
from ooodev.utils.data_type.color_range import ColorRange as ColorRange
from ooodev.utils.data_type.intensity import Intensity as Intensity
from ooodev.utils.data_type.intensity_range import IntensityRange as IntensityRange
from ooodev.utils.data_type.size_mm import SizeMM as SizeMM

__all__ = ["Color", "Gradient", "Hatch", "Img", "Pattern"]
